@@ -1,4 +1,5 @@
 import ctypes
+import time
 import tkinter as tk
 import tkinter.ttk as ttk
 from ctypes import windll, POINTER, Structure, c_bool, sizeof, windll, pointer, c_int, c_char, c_long, c_ulong
@@ -280,20 +281,6 @@ def window_move(widget: tk.Widget, window: tk.Tk):
     widget.bind("<B1-Motion>", move)
 
 
-def window_dark(window: tk.Tk):
-    """
-    设置黑暗主题
-    """
-    dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), DWMWA_USE_IMMERSIVE_DARK_MODE, True)
-
-
-def window_light(window: tk.Tk):
-    """
-    设置明亮主题
-    """
-    dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), DWMWA_USE_IMMERSIVE_DARK_MODE, False)
-
-
 def window_screenshot(window: tk.Tk, image_name: str = "Image.png"):
     """
     截取窗口图片
@@ -621,6 +608,42 @@ def resize_widget(widget: tk.Widget, size: int = 10):
         pass
 
 
+def window_theme_dark(window: tk.Tk):
+    import ctypes
+    window.update()
+    DWMWA_USE_IMMERSIVE_DARK_MODE = 20
+    SetWindowAttribute = ctypes.windll.dwmapi.DwmSetWindowAttribute
+    hWnd = GetParent(window.winfo_id())
+    Value = 2
+    Value = ctypes.c_int(Value)
+    SetWindowAttribute(hWnd, DWMWA_USE_IMMERSIVE_DARK_MODE, ctypes.byref(Value),
+                       ctypes.sizeof(Value))
+
+
+def window_theme_light(window: tk.Tk):
+    import ctypes
+    window.update()
+    DWMWA_USE_IMMERSIVE_LIGHT_MODE = 21
+    SetWindowAttribute = ctypes.windll.dwmapi.DwmSetWindowAttribute
+    hWnd = GetParent(window.winfo_id())
+    Value = 2
+    Value = ctypes.c_int(Value)
+    SetWindowAttribute(hWnd, DWMWA_USE_IMMERSIVE_LIGHT_MODE, ctypes.byref(Value),
+                       ctypes.sizeof(Value))
+
+
+def window_theme_none(window: tk.Tk):
+    import ctypes
+    window.update()
+    DWMWA_USE_IMMERSIVE_LIGHT_MODE = 21
+    SetWindowAttribute = ctypes.windll.dwmapi.DwmSetWindowAttribute
+    hWnd = GetParent(window.winfo_id())
+    Value = 0
+    Value = ctypes.c_int(Value)
+    SetWindowAttribute(hWnd, DWMWA_USE_IMMERSIVE_LIGHT_MODE, ctypes.byref(Value),
+                       ctypes.sizeof(Value))
+
+
 def Error(text):
     try:
         from colorama import Fore
@@ -1441,9 +1464,12 @@ class DevWindow(tk.Tk):
 
     def seed_notification(self, title: str = "", message: str = "", app_name: str = "Python", app_icon="",
                           time_out: int = 0):
-        Notification = DevNotification(title=title, message=message, app_name=app_name, app_icon=app_icon,
-                                       timeout=time_out)
-        Notification.show()
+        def show():
+            Notification = DevNotification(title=title, message=message, app_name=app_name, app_icon=app_icon,
+                                           timeout=time_out)
+            Notification.show()
+
+        self.after(1000, show)
 
     def dpi(self):
         """
@@ -1452,6 +1478,144 @@ class DevWindow(tk.Tk):
         self.tk.call('tk', 'scaling', ScaleFactor / 75)
 
 
+class DevManage(object):
+    def __init__(self, master: tk.Tk):
+        self._master = GetParent(master.winfo_id())
+
+    def set_master(self, master: tk.Tk):
+        SetParent(self._master, GetParent(master.winfo_id()))
+
+    def set_window_long(self, setting):
+        return SetWindowLong(self._master, GWL_STYLE, setting)
+
+    def set_window_ex_long(self, setting):
+        return SetWindowLong(self._master, GWL_EXSTYLE, setting)
+
+    def set_window_popup(self):
+        return self.set_window_long(WS_POPUP)
+
+    def set_window_popup_window(self):
+        return self.set_window_long(WS_POPUPWINDOW)
+
+    def set_window_init_minimize(self):
+        return self.set_window_long(WS_MINIMIZE)
+
+    def set_window_init_maximize(self):
+        return self.set_window_long(WS_MAXIMIZE)
+
+    def set_window_init_disable(self):
+        return self.set_window_long(WS_DISABLED)
+
+    def set_window_init_visible(self):
+        return self.set_window_long(WS_VISIBLE)
+
+    def set_window_sysmenu(self):
+        return self.set_window_long(WS_SYSMENU)
+
+    def set_window_toolwindow(self):
+        return self.set_window_ex_long(WS_EX_TOOLWINDOW)
+
+    def set_window_maximizebox(self):
+        return self.set_window_long(WS_MAXIMIZEBOX)
+
+    def set_window_minimizebox(self):
+        return self.set_window_long(WS_MINIMIZEBOX)
+
+    def set_window_caption(self):
+        return self.set_window_long(WS_CAPTION)
+
+    def set_window_titlebar(self):
+        return self.set_window_long(WS_CAPTION)
+
+    def set_window_border(self):
+        return self.set_window_long(WS_BORDER)
+
+    def set_window_dlg_frame(self):
+        return self.set_window_long(WS_DLGFRAME)
+
+    def set_window_think_frame(self):
+        return self.set_window_long(WS_THICKFRAME)
+
+    def set_window_resize_border_frame(self):
+        return self.set_window_long(WS_THICKFRAME)
+
+    def set_window_child(self):
+        return self.set_window_long(WS_CHILD)
+
+    def get_window_long(self):
+        return GetWindowLong(self._master, GWL_STYLE)
+
+    def get_window_ex_long(self):
+        return GetWindowLong(self._master, GWL_EXSTYLE)
+
+    def add_window_popup(self):
+        return self.add_window_long(WS_POPUP)
+
+    def add_window_long(self, setting):
+        return SetWindowLong(self._master, GWL_STYLE, self.get_window_long() & ~setting)
+
+    def add_window_ex_long(self, setting):
+        return SetWindowLong(self._master, GWL_EXSTYLE, self.get_window_ex_long() & ~setting)
+
+    def add_window_popup_window(self):
+        return self.add_window_long(WS_POPUPWINDOW)
+
+    def add_window_init_minimize(self):
+        return self.add_window_long(WS_MINIMIZE)
+
+    def add_window_init_maximize(self):
+        return self.add_window_long(WS_MAXIMIZE)
+
+    def add_window_init_disable(self):
+        return self.add_window_long(WS_DISABLED)
+
+    def add_window_init_visible(self):
+        return self.add_window_long(WS_VISIBLE)
+
+    def add_window_sysmenu(self):
+        return self.add_window_long(WS_SYSMENU)
+
+    def add_window_toolwindow(self):
+        return self.add_window_ex_long(WS_EX_TOOLWINDOW)
+
+    def add_window_maximizebox(self):
+        return self.add_window_long(WS_MAXIMIZEBOX)
+
+    def add_window_minimizebox(self):
+        return self.add_window_long(WS_MINIMIZEBOX)
+
+    def add_window_caption(self):
+        return self.add_window_long(WS_CAPTION)
+
+    def add_window_titlebar(self):
+        return self.add_window_long(WS_CAPTION)
+
+    def add_window_border(self):
+        return self.add_window_long(WS_BORDER)
+
+    def add_window_dlg_frame(self):
+        return self.add_window_long(WS_DLGFRAME)
+
+    def add_window_think_frame(self):
+        return self.add_window_long(WS_THICKFRAME)
+
+    def add_window_resize_border_frame(self):
+        return self.add_window_long(WS_THICKFRAME)
+
+    def add_window_child(self):
+        return self.add_window_long(WS_CHILD)
+
+    def release_capture(self):
+        return ReleaseCapture()
+
+    def send_message(self, event, func):
+        self.release_capture()
+        return SendMessage(self._master, event, func, 0)
+
+    def send_message_maximize(self):
+        self.send_message(WM_COMMAND, SC_MAXIMIZE)
+
+
 class DevToplevel(tk.Toplevel, DevWindow):
     def __init__(self, master: tk.Tk = None, title: str = ""):
         super(DevToplevel, self).__init__(master=master)
@@ -1575,4 +1739,4 @@ class DevTooltip(DevToplevel):
 
 
 if __name__ == '__main__':
-    Install("notify2")
\ No newline at end of file
+    Install("progressbar")
\ No newline at end of file
