@@ -1,6 +1,7 @@
 import urllib.request
 from os import mkdir, environ, system, remove
 from os.path import exists, expanduser
+from sys import executable
 from time import sleep
 
 
@@ -12,41 +13,45 @@ def is64():
     return 'PROGRAMFILES(X86)' in environ
 
 
+pbar = 0
+
+
+def show_progress(block_num, block_size, total_size):
+    global pbar
+    pbar = pbar + block_size
+    progress = tqdm(total=total_size, colour="#728efd", ncols=120, position=0)
+    progress.set_description("安装进度")
+    progress.update(pbar)
+    progress.close()
+
+
 def install(url_file, path):
+    global pbar
     import requests
     import zipfile
+
     console("开始下载 : " + url_file)
 
-    urllib.request.urlretrieve(url_file, path)
+    urllib.request.urlretrieve(url_file, path, show_progress)
     file = zipfile.ZipFile(path, "r")
     console("开始检验压缩包是否损坏...")
     file.testzip()
-    for list in file.namelist():
-        console("压缩包内的文件 : " + list)
+    pbar = 0
+    # for list in file.namelist():
+    #    console("压缩包内的文件 : " + list)
 
 
-console("获取个人文件夹中")
 user_path = expanduser("~")
-console("获取成功！位置在：" + user_path)
-console("准备创建 .tkdev 文件夹...")
-console("检测 .tkdev 是否已经存在...")
 tkdev_path = user_path + "\\.tkdev"
 if exists(tkdev_path):
-    console("检测到 .tkdev 已经存在！")
+    pass
 else:
-    console("未检测到 .tkdev ，准备开始创建 .tkdev 文件夹！")
     mkdir(tkdev_path)
-    console("创建成功！")
-console(".tkdev文件夹位置在：" + tkdev_path)
-console("开始检查工具文件夹是否创建好！")
 tkdev_tools_path = tkdev_path + "\\tools"
 if exists(tkdev_tools_path):
-    console("检测到 tools 已经存在！")
+    pass
 else:
-    console("未检测到 tools ，准备开始创建 tools 文件夹！")
     mkdir(tkdev_tools_path)
-    console("创建成功！")
-console("开始检查工具是否创建好...")
 
 if is64():
     tkdev_winico_path = tkdev_tools_path + "\\Winico64.zip"
@@ -54,7 +59,7 @@ if is64():
 else:
     tkdev_winico_path = tkdev_tools_path + "\\Winico32.zip"
     tkdev_twapi_path = tkdev_tools_path + "\\twapi.zip"
-
+from tqdm import tqdm, trange
 if exists(tkdev_winico_path):
     console("检测到已经安装好Winico！")
 else:
@@ -73,3 +78,5 @@ else:
 
 console("安装完成！")
 console("初始化完毕！")
+
+system("pause")
