@@ -356,10 +356,7 @@ class DevTwApi(object):
         from win32gui import GetParent
         self._master = master
 
-        def get_hwin():
-            self._hwin = GetParent(self._master.winfo_id())
-
-        self._master.after(100, lambda: get_hwin())
+        self._hwin = GetParent(self._master.winfo_id())
 
     def twapi(self, command, hwin):
         return self._master.tk.call(f"twapi::{command}", hwin)
@@ -373,7 +370,7 @@ class DevTwApi(object):
     def get_parent_window(self):
         return self.twapi("get_parent_window")
 
-    def get_window_text(self):
+    def get_window_text(self, hwin):
         return self._master.tk.call('twapi', "get_window_text")
 
     def minimize_window(self, hwin):
@@ -394,9 +391,6 @@ class DevTwApi(object):
 
 
 if __name__ == '__main__':
-    from win32gui import GetParent
     root = tkinter.Tk()
-    twapi = DevTwApi(root)
-    twapi.use_twapi_all()
-    root.tk.call('twapi::window_maximized', "-hwin", GetParent(root.winfo_id()))
+    DevTray(root).show()
     root.mainloop()
